@@ -7,17 +7,15 @@ ch = logging.StreamHandler(stream=sys.stderr)
 ch.setLevel(os.getenv("LOG_LEVEL", "INFO"))
 
 logger.setLevel(os.getenv("LOG_LEVEL", "INFO"))
-logger.addHandler(ch)
 
 def getLogger(name, toFile=False):
     logger = logging.getLogger(name)
-
-
     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s -%(message)s')
-    ch.setLevel(os.getenv("LOG_LEVEL", "INFO"))
+    ch.setLevel(os.getenv("LOG_LEVEL", "DEBUG"))
     ch.setFormatter(formatter)
     logger.setLevel(os.getenv("LOG_LEVEL", "INFO"))
-    logger.addHandler(ch)
+
+    # logger.addHandler(ch)
     if not os.path.exists('/tmp/logs/'):
         os.mkdir('/tmp/logs')
     if toFile:
